[前][次][番号順一覧][スレッド一覧]

ruby-changes:27951

From: usa <ko1@a...>
Date: Sat, 30 Mar 2013 04:00:13 +0900 (JST)
Subject: [ruby-changes:27951] usa:r40003 (trunk): * win32/file.c (code_page): use cp1252 instead of cp20127 as US-ASCII.

usa	2013-03-30 04:00:05 +0900 (Sat, 30 Mar 2013)

  New Revision: 40003

  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=rev&revision=40003

  Log:
    * win32/file.c (code_page): use cp1252 instead of cp20127 as US-ASCII.
      fix [ruby-core:53079] [Bug #7996]
      reported and patched by mmeltner (Michael Meltner).

  Modified files:
    trunk/ChangeLog
    trunk/win32/file.c

Index: ChangeLog
===================================================================
--- ChangeLog	(revision 40002)
+++ ChangeLog	(revision 40003)
@@ -1,10 +1,16 @@ https://github.com/ruby/ruby/blob/trunk/ChangeLog#L1
+Sat Mar 30 03:58:00 2013  NAKAMURA Usaku  <usa@r...>
+
+	* win32/file.c (code_page): use cp1252 instead of cp20127 as US-ASCII.
+	  fix [ruby-core:53079] [Bug #7996]
+	  reported and patched by mmeltner (Michael Meltner).
+
 Sat Mar 30 03:49:21 2013  NAKAMURA Usaku  <usa@r...>
 
 	* win32/win32.c (wrename): use MoveFileExW instead of MoveFileW,
 	  because the latter fails on cross device file move of some
 	  environments.
 	  fix [ruby-core:53492] [Bug #8109]
-	  reported by mitchellh (Mitchell Hashimoto)
+	  reported by mitchellh (Mitchell Hashimoto).
 
 Fri Mar 29 22:09:46 2013  Nobuyoshi Nakada  <nobu@r...>
 
Index: win32/file.c
===================================================================
--- win32/file.c	(revision 40002)
+++ win32/file.c	(revision 40003)
@@ -212,9 +212,9 @@ code_page(rb_encoding *enc) https://github.com/ruby/ruby/blob/trunk/win32/file.c#L212
 	names_ary = rb_funcall(encoding, names, 0);
     }
 
     /* map US-ASCII and ASCII-8bit as code page 20127 (us-ascii) */
     if (enc == rb_usascii_encoding() || enc == rb_ascii8bit_encoding()) {
-	UINT code_page = 20127;
+	UINT code_page = 1252;
 	rb_hash_aset(rb_code_page, name_key, INT2FIX(code_page));
 	return code_page;
     }
@@ -212,9 +212,9 @@ code_page(rb_encoding *enc) https://github.com/ruby/ruby/blob/trunk/win32/file.c#L212
     }
 
-    /* map US-ASCII and ASCII-8bit as code page 20127 (us-ascii) */
+    /* map US-ASCII and ASCII-8bit as code page 1252 (us-ascii) */
     if (enc == rb_usascii_encoding() || enc == rb_ascii8bit_encoding()) {

--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]